@@ -1,7 +1,13 @@
 package BasicApp;
 use Mojo::Base 'Mojolicious', -signatures;
 
-our ($LAST_VALIDATE_RESPONSE_RESULT, $LAST_VALIDATE_RESPONSE_STASH);
+our ($LAST_VALIDATE_REQUEST_STASH, $LAST_VALIDATE_RESPONSE_RESULT, $LAST_VALIDATE_RESPONSE_STASH);
+
+Class::Method::Modifiers::before('Test::Mojo::_request_ok' => sub {
+  undef $LAST_VALIDATE_REQUEST_STASH;
+  undef $LAST_VALIDATE_RESPONSE_RESULT;
+  undef $LAST_VALIDATE_RESPONSE_STASH;
+});
 
 sub startup ($self) {
   $self->plugin('OpenAPI::Modern', $self->config->{openapi});
@@ -12,10 +18,10 @@ sub startup ($self) {
 
   $routes->any('/foo*catchall' => sub ($c) {
     my $result = $c->validate_request;
+    $LAST_VALIDATE_REQUEST_STASH = $c->stash('openapi');
     $c->render(
       status => $c->req->query_params->param('status') // ($result ? 200 : 400),
       json => {
-        stash => $c->stash('openapi'),
         result => $result,
       },
     );
